import { aws_sns as sns } from 'aws-cdk-lib';
import { Construct } from 'constructs';
/**
 * Enumeration of priority for Alarms.
 *
 * The `Priority` enum is used to represent the priority of an Alarm. It has five possible values.
 */
export declare enum Priority {
    /** indicates that the alarm is of the highest priority and requires immediate attention. */
    CRITICAL = "p1",
    /** indicates that the alarm is of high priority and should be addressed as soon as possible. */
    HIGH = "p2",
    /** indicates that the alarm is of medium priority and can be addressed in due course. */
    MEDIUM = "p3",
    /** indicates that the alarm is of low priority and can be addressed at a later time. */
    LOW = "p4",
    /** indicates that the alarm is of the lowest priority and can be addressed at a later time. */
    INFORMATION = "p5"
}
export declare class SnsNotifyOpsgenie extends Construct {
    private readonly scope;
    constructor(scope: Construct, id: string);
    /**
     * Returns an sns.Topic object that represents an SNS topic in AWS.
     * The topic ARN is constructed based on the accountId, priority, and region parameters.
     *
      * @param accountId The AWS account ID where the topic is located.
      * @param priority The priority of the topic. Must be one of @enum Priority
      * @param region The AWS region where the topic is located. If not specified, defaults to eu-west-1.
      * @returns An sns.Topic object that represents an SNS topic in AWS.
      */
    getOpgsgenieTopicArn(accountId: string, priority: Priority, region?: string): sns.ITopic;
}
